@@ -467,26 +467,26 @@ if __name__ == '__main__':
 
     def main():
         run = True
-        input_box = InputBox(100, 100, 250, 50,  anfangs_anzeige_text=["lol", "rutsch"],
+        ib = InputBox(100, 100, 250, 50,  anfangs_anzeige_text=["test"],
                              umrandung="rect", input_anfangs_active=False, vergroserungs_richtung="beide",
                              font_size_height_rel=1, zeilen_abstand_rel=0.7, binde_seite="links", label= "Test:", label_x= 200, 
-                              label_abstand_x= 100)
+                              label_abstand_x= 100, mit_zeilen_umbruch=True)
 
         while run:
             CLOCK.tick(FPS)
             for event in pygame.event.get():
                 if event.type == pygame.QUIT:
                     run = False
-                if event.type == pygame.KEYDOWN:
-                    if event.key == pygame.K_r:
-                        input_box.set_input_text_value("34:54")
+                # if event.type == pygame.KEYDOWN:
+                #     if event.key == pygame.K_r:
+                #         input_box.set_input_text_value("34:54")
                     
-                input_box.event_check(event)
+                ib.event_check(event)
 
-            input_box.update()
+            ib.update()
 
             draw()
-            input_box.draw(WIN)
+            ib.draw(WIN)
 
             pygame.display.update()
 
